==> scriptcase-9.12.011-php8.1.zip: scriptcase-9.12.011-php8.1/devel/lib/php/fixs/290.fixV8ChartsXml.php <==
<?php

{
    $arr_path   = array(
        //'sys'        => $nm_config['path_sys'],
        'grp'        => $nm_config['path_grp'],
        //'usr'        => $nm_config['path_usr'],
    );

    $arr_list = array();
    foreach ($arr_path as $str_mod => $str_path)
    {
        if($str_mod == 'scriptcase' || $str_mod == 'sys')
        {
            if(is_dir($str_path . "schema/"))
            {
                $arr_schemas = array_diff(scandir($str_path. "chart/"), array('.','..', 'index.html'));
                if(isset($arr_schemas) && is_array($arr_schemas) && !empty($arr_schemas))
                {
                    foreach($arr_schemas as $schema)
                    {
                        if(substr($schema, -3) == 'ini')
                        {
                            $arr_list[$str_mod . '__NM__' . $schema] = $str_path . "schema/" . $schema;
                        }
                    }
                }
            }
        }
        else
        {
            $arr_childs = array_diff(scandir($str_path), array('.','..', 'index.html'));
            if(isset($arr_childs) && is_array($arr_childs) && !empty($arr_childs))
            {
                foreach($arr_childs as $childs)
                {
                    if(is_dir($str_path . $childs) && is_dir($str_path . $childs . "/chart/"))
                    {
                        $arr_schemas = array_diff(scandir($str_path . $childs . "/chart/"), array('.','..', 'index.html'));
                        if(isset($arr_schemas) && is_array($arr_schemas) && !empty($arr_schemas))
                        {
                            foreach($arr_schemas as $schema)
                            {
                                if(substr($schema, -3) == 'ini')
                                {
                                    $arr_list[$str_mod . '__NM__' . $schema] = $str_path . $childs . "/chart/" . $schema;
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    if(!empty($arr_list))
    {
        foreach($arr_list as $schema)
        {
            $_schema = file_get_contents($schema);

            if(strpos($_schema, "<?xml") !== false)
            {
                $arr_default = unserialize(file_get_contents($nm_config['path_scriptcase'] . '/chart/sc_Clean.ini'));
                if(function_exists("simplexml_load_string"))
                {
                    $arr_schema = simplexml_load_string($_schema);
                    $arr_default['schema']['borderColor'] = (string)$arr_schema->css_chart_border_color[0];
                    $arr_default['schema']['bgColor'] = (string)$arr_schema->css_chart_background_color[0];
                    $arr_default['schema']['canvasBgColor'] = (string)$arr_schema->css_chart_background_color[0];
                    $arr_default['schema']['captionFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['subCaptionFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['xAxisNameFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['yAxisNameFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['labelFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['valueFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['legendCaptionFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['legendItemFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                }
                file_put_contents($schema, serialize($arr_default));
            }
        }
    }
}

$return = true;

==> scriptcase-9.13.006-php8.1.zip: scriptcase-9.13.006-php8.1/devel/lib/php/fixs/290.fixV8ChartsXml.php <==
<?php

{
    $arr_path   = array(
        //'sys'        => $nm_config['path_sys'],
        'grp'        => $nm_config['path_grp'],
        //'usr'        => $nm_config['path_usr'],
    );

    $arr_list = array();
    foreach ($arr_path as $str_mod => $str_path)
    {
        if($str_mod == 'scriptcase' || $str_mod == 'sys')
        {
            if(is_dir($str_path . "schema/"))
            {
                $arr_schemas = array_diff(scandir($str_path. "chart/"), array('.','..', 'index.html'));
                if(isset($arr_schemas) && is_array($arr_schemas) && !empty($arr_schemas))
                {
                    foreach($arr_schemas as $schema)
                    {
                        if(substr($schema, -3) == 'ini')
                        {
                            $arr_list[$str_mod . '__NM__' . $schema] = $str_path . "schema/" . $schema;
                        }
                    }
                }
            }
        }
        else
        {
            $arr_childs = array_diff(scandir($str_path), array('.','..', 'index.html'));
            if(isset($arr_childs) && is_array($arr_childs) && !empty($arr_childs))
            {
                foreach($arr_childs as $childs)
                {
                    if(is_dir($str_path . $childs) && is_dir($str_path . $childs . "/chart/"))
                    {
                        $arr_schemas = array_diff(scandir($str_path . $childs . "/chart/"), array('.','..', 'index.html'));
                        if(isset($arr_schemas) && is_array($arr_schemas) && !empty($arr_schemas))
                        {
                            foreach($arr_schemas as $schema)
                            {
                                if(substr($schema, -3) == 'ini')
                                {
                                    $arr_list[$str_mod . '__NM__' . $schema] = $str_path . $childs . "/chart/" . $schema;
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    if(!empty($arr_list))
    {
        foreach($arr_list as $schema)
        {
            $_schema = file_get_contents($schema);

            if(strpos($_schema, "<?xml") !== false)
            {
                $arr_default = unserialize(file_get_contents($nm_config['path_scriptcase'] . '/chart/sc_Clean.ini'), ['allowed_classes' => false]);
                if(function_exists("simplexml_load_string"))
                {
                    $arr_schema = simplexml_load_string($_schema);
                    $arr_default['schema']['borderColor'] = (string)$arr_schema->css_chart_border_color[0];
                    $arr_default['schema']['bgColor'] = (string)$arr_schema->css_chart_background_color[0];
                    $arr_default['schema']['canvasBgColor'] = (string)$arr_schema->css_chart_background_color[0];
                    $arr_default['schema']['captionFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['subCaptionFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['xAxisNameFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['yAxisNameFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['labelFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['valueFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['legendCaptionFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                    $arr_default['schema']['legendItemFontColor'] = (string)$arr_schema->css_chart_font_color[0];
                }
                file_put_contents($schema, serialize($arr_default));
            }
        }
    }
}

$return = true;
